@@ -3,8 +3,7 @@
 Example of program which uses [options] shortcut in pattern.
 
 Usage:
-  lesscode_tool (new -d dir [-p project]|sqlacodegen -u url [-t table][-f file])
-
+  lesscodeTool (new -d dir [-p project]|sqlacodegen -u url [-t table][-f file])
 Options:
   -h, --help                查看帮助
   -v, --version            展示版本号
